﻿using System;
using System.Collections.Generic;
using Lephone.Data.Definition;
using Lephone.Linq;

namespace VisualWiki.Models
{
    public abstract class Article : LinqObjectModel<Article>
    {
        [Length(1, 255), Index(UNIQUE = true)]
        public abstract string Title { get; set; }

        public abstract string Content { get; set; }

        [SpecialName]
        public abstract DateTime SavedOn { get; set; }

        [HasMany(OrderBy = "CreatedOn DESC, Id DESC")]
        public abstract IList<ArticleHistory> History { get; set; }

        public abstract Article Init(string title, string content);

        public static Article FindByTitle(string title)
        {
            return FindOne(p => p.Title == title);
        }

        public static void SaveArticle(string title, string content)
        {
            var article = FindByTitle(title);
            if(article == null)
            {
                article = New.Init(title, content);
            }
            else
            {
                article.History.Add(ArticleHistory.New.Init(article));
                article.Content = content;
            }
            article.Save();
        }
    }
}
