﻿using System.Text;
using System.Web.UI.WebControls;
using Lephone.Util;
using Lephone.Web;

namespace VisualWiki.Models.Helpers
{
    public static class CommonHelper
    {
        public static void SetLink(HyperLink link, string pageName, string linkPageName, string title)
        {
            if (pageName.ToLower() == linkPageName.ToLower())
            {
                link.Enabled = false;
            }
            else
            {
                link.Enabled = true;
                link.NavigateUrl = new UrlBuilder(linkPageName).Add(Const.TitleName, title).ToString();
            }
        }

        public static string GenerateShowText(string text)
        {
            return ProcessSymbol(text, "[[", "]]",
                title =>
                {
                    var url = new UrlBuilder("Show.aspx");
                    url.Add(Const.TitleName, RemoveHtmlTag(title));
                    var link = HtmlBuilder.New.a(url.ToString()).include(title).end;
                    return link.ToString();
                });
        }

        public static string RemoveHtmlTag(string text)
        {
            return ProcessSymbol(text, "<", ">", null);
        }

        public static string ProcessSymbol(string text, string left, string right, 
            CallbackHandler<string, string> callback)
        {
            var ret = new StringBuilder();
            int last = 0;
            while (true)
            {
                int m = text.IndexOf(left, last);
                if (m >= last)
                {
                    int n = text.IndexOf(right, m);
                    if (n > m)
                    {
                        ret.Append(text.Substring(last, m - last));
                        if(callback != null)
                        {
                            var inner = text.Substring(m + left.Length, n - m - left.Length);
                            ret.Append(callback(inner));
                        }
                        last = n + right.Length;
                        continue;
                    }
                }
                ret.Append(text.Substring(last));
                break;
            }
            return ret.ToString();
        }
    }
}
