﻿using NUnit.Framework;
using VisualWiki.Models.Helpers;

namespace VisualWiki.UnitTests
{
    [TestFixture]
    public class TestHelper
    {
        [Test]
        public void TestTestGenerateShowTest1()
        {
            const string text = "abc [[bb]] xyz";
            var act = CommonHelper.GenerateShowText(text);
            Assert.AreEqual("abc <a href=\"Show.aspx?title=bb\">bb</a> xyz", act);
        }

        [Test]
        public void TestTestGenerateShowTest2()
        {
            const string text = "abc [[bb xyz";
            var act = CommonHelper.GenerateShowText(text);
            Assert.AreEqual("abc [[bb xyz", act);
        }

        [Test]
        public void TestTestGenerateShowTest3()
        {
            const string text = "abc bb]] xyz";
            var act = CommonHelper.GenerateShowText(text);
            Assert.AreEqual("abc bb]] xyz", act);
        }

        [Test]
        public void TestTestGenerateShowTest4()
        {
            const string text = "[[bb]]";
            var act = CommonHelper.GenerateShowText(text);
            Assert.AreEqual("<a href=\"Show.aspx?title=bb\">bb</a>", act);
        }

        [Test]
        public void TestTestGenerateShowTest5()
        {
            const string text = "[[x<b>y</b>z]]";
            var act = CommonHelper.GenerateShowText(text);
            Assert.AreEqual("<a href=\"Show.aspx?title=xyz\">x<b>y</b>z</a>", act);
        }

        [Test]
        public void TestTestGenerateShowTest6()
        {
            const string text = "[[bb]] aa [[cc]]";
            var act = CommonHelper.GenerateShowText(text);
            Assert.AreEqual("<a href=\"Show.aspx?title=bb\">bb</a> aa <a href=\"Show.aspx?title=cc\">cc</a>", act);
        }

        [Test]
        public void TestProcessSymbol()
        {
            var result = CommonHelper.ProcessSymbol("[[abc)", "[[", ")", text => text);
            Assert.AreEqual("abc", result);

            result = CommonHelper.ProcessSymbol("1111[[[[abc)2222", "[[[[", ")", text => text);
            Assert.AreEqual("1111abc2222", result);

            result = CommonHelper.ProcessSymbol("1111(abc]]]]2222", "(", "]]]]", text => text);
            Assert.AreEqual("1111abc2222", result);
        }
    }
}
